@@ -1,7 +1,11 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import
+
 from django.contrib import admin
 from django.core.urlresolvers import reverse
 
+from ..utils.compatibility import LTE_DJANGO_1_7
+
 
 class PrimitivePermissionAwareModelAdmin(admin.ModelAdmin):
     def has_add_permission(self, request):
@@ -24,11 +28,16 @@ class PrimitivePermissionAwareModelAdmin(admin.ModelAdmin):
         return self.has_change_permission(request, obj)
 
     def _get_post_url(self, obj):
-        """ Needed to retrieve the changelist url as Folder/File can be extended
-        and admin url may change """
-        ## Code borrowed from django ModelAdmin to determine changelist on the fly
+        """
+        Needed to retrieve the changelist url as Folder/File can be extended
+        and admin url may change
+        """
+        # Code from django ModelAdmin to determine changelist on the fly
         opts = obj._meta
-        module_name = opts.module_name
+        if LTE_DJANGO_1_7:
+            model_name = opts.module_name
+        else:
+            model_name = opts.model_name
         return reverse('admin:%s_%s_changelist' %
-                       (opts.app_label, module_name),
+                       (opts.app_label, model_name),
             current_app=self.admin_site.name)
