@@ -1,12 +1,18 @@
-from filer.fields.file import AdminFileWidget, AdminFileFormField, FilerFileField
-from filer.models import Image
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import
+
+from ..models import Image
+from .file import AdminFileFormField, AdminFileWidget, FilerFileField
+
 
 class AdminImageWidget(AdminFileWidget):
     pass
 
+
 class AdminImageFormField(AdminFileFormField):
     widget = AdminImageWidget
 
+
 class FilerImageField(FilerFileField):
     default_form_class = AdminImageFormField
-    default_model_class = Image
\ No newline at end of file
+    default_model_class = Image
