@@ -1,4 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import
+
 import base64
 import hashlib
 import warnings
@@ -6,13 +8,11 @@ from io import BytesIO
 
 from django.core.files.base import ContentFile
 from django.utils import six
+from easy_thumbnails import fields as easy_thumbnails_fields
+from easy_thumbnails import files as easy_thumbnails_files
 
-from easy_thumbnails import (fields as easy_thumbnails_fields,
-                             files as easy_thumbnails_files)
-
-from filer import settings as filer_settings
-from filer.utils.filer_easy_thumbnails import ThumbnailerNameMixin
-
+from .. import settings as filer_settings
+from ..utils.filer_easy_thumbnails import ThumbnailerNameMixin
 
 STORAGES = {
     'public': filer_settings.FILER_PUBLICMEDIA_STORAGE,
@@ -91,7 +91,7 @@ class MultiStorageFieldFile(ThumbnailerNameMixin,
             return self.thumbnail_options['private'].get('base_dir', '')
 
     def save(self, name, content, save=True):
-        content.seek(0) # Ensure we upload the whole file
+        content.seek(0)  # Ensure we upload the whole file
         super(MultiStorageFieldFile, self).save(name, content, save)
 
 
@@ -100,17 +100,18 @@ class MultiStorageFileField(easy_thumbnails_fields.ThumbnailerField):
 
     def __init__(self, verbose_name=None, name=None,
                  storages=None, thumbnail_storages=None, thumbnail_options=None, **kwargs):
-        if 'upload_to' in kwargs:
+        if 'upload_to' in kwargs:  # pragma: no cover
             upload_to = kwargs.pop("upload_to")
-            warnings.warn("MultiStorageFileField can handle only File objects;"
-                          "%s passed" % upload_to, SyntaxWarning)
+            if upload_to != generate_filename_multistorage:
+                warnings.warn("MultiStorageFileField can handle only File objects;"
+                              "%s passed" % upload_to, SyntaxWarning)
         self.storages = storages or STORAGES
         self.thumbnail_storages = thumbnail_storages or THUMBNAIL_STORAGES
         self.thumbnail_options = thumbnail_options or THUMBNAIL_OPTIONS
         super(easy_thumbnails_fields.ThumbnailerField, self).__init__(
-                                      verbose_name=verbose_name, name=name,
-                                      upload_to=generate_filename_multistorage,
-                                      storage=None, **kwargs)
+            verbose_name=verbose_name, name=name,
+            upload_to=generate_filename_multistorage,
+            storage=None, **kwargs)
 
     def value_to_string(self, obj):
         value = super(MultiStorageFileField, self).value_to_string(obj)
