@@ -1,21 +1,24 @@
-#-*- coding: utf-8 -*-
-import os
-try:
-    from PIL import Image as PILImage
-except ImportError:
-    try:
-        import Image as PILImage
-    except ImportError:
-        raise ImportError("The Python Imaging Library was not found.")
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import
 
+import logging
+import os
+
+from distutils.version import LooseVersion
+from django import get_version
 from django.db import models
 from django.utils import six
 from django.utils.translation import ugettext_lazy as _
 
-from filer import settings as filer_settings
-from filer.models.filemodels import File
-from filer.utils.filer_easy_thumbnails import FilerThumbnailer
-from filer.utils.pil_exif import get_exif_for_file
+from .. import settings as filer_settings
+from ..utils.compatibility import PILImage
+from ..utils.filer_easy_thumbnails import FilerThumbnailer
+from ..utils.pil_exif import get_exif_for_file
+from .filemodels import File
+
+logger = logging.getLogger(__name__)
+
+DJANGO_GTE_17 = LooseVersion(get_version()) >= LooseVersion('1.7.0')
 
 
 class BaseImage(File):
@@ -23,7 +26,7 @@ class BaseImage(File):
     DEFAULT_THUMBNAILS = {
         'admin_clipboard_icon': {'size': (32, 32), 'crop': True,
                                  'upscale': True},
-        'admin_sidebar_preview': {'size': (SIDEBAR_IMAGE_WIDTH, 10000)},
+        'admin_sidebar_preview': {'size': (SIDEBAR_IMAGE_WIDTH, 10000), 'upscale': True},
         'admin_directory_listing_icon': {'size': (48, 48),
                                          'crop': True, 'upscale': True},
         'admin_tiny_icon': {'size': (32, 32), 'crop': True, 'upscale': True},
@@ -37,8 +40,11 @@ class BaseImage(File):
     default_alt_text = models.CharField(_('default alt text'), max_length=255, blank=True, null=True)
     default_caption = models.CharField(_('default caption'), max_length=255, blank=True, null=True)
 
-    subject_location = models.CharField(_('subject location'), max_length=64, null=True, blank=True,
-                                        default=None)
+    subject_location = models.CharField(_('subject location'), max_length=64, blank=True,
+                                        default='')
+    if DJANGO_GTE_17:
+        file_ptr = models.OneToOneField(to='filer.File', related_name='%(app_label)s_%(class)s_file',
+                                        on_delete=models.CASCADE)
 
     @classmethod
     def matches_file_type(cls, iname, ifile, request):
@@ -77,7 +83,7 @@ class BaseImage(File):
             return self._exif_cache
         else:
             if self.file:
-                self._exif_cache = get_exif_for_file(self.file.path)
+                self._exif_cache = get_exif_for_file(self.file)
             else:
                 self._exif_cache = {}
         return self._exif_cache
@@ -136,7 +142,7 @@ class BaseImage(File):
                 # purposes and/or just logging it, provided user configured
                 # proper logging configuration
                 if filer_settings.FILER_ENABLE_LOGGING:
-                    logger.error('Error while generating thumbnail: %s',e)
+                    logger.error('Error while generating thumbnail: %s', e)
                 if filer_settings.FILER_DEBUG:
                     raise
         return _thumbnails
@@ -164,7 +170,7 @@ class BaseImage(File):
             thumbnail_basedir=self.file.thumbnail_basedir)
         return tn
 
-    class Meta:
+    class Meta(object):
         app_label = 'filer'
         verbose_name = _('image')
         verbose_name_plural = _('images')
