@@ -1,19 +1,28 @@
-#-*- coding: utf-8 -*-
-from __future__ import unicode_literals
+# -*- coding: utf-8 -*-
+
+from __future__ import absolute_import, unicode_literals
+
+import hashlib
+import os
 
-from django.core import urlresolvers
 from django.conf import settings
+from django.core import urlresolvers
 from django.core.files.base import ContentFile
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from filer.fields.multistorage_file import MultiStorageFileField
-from filer.models import mixins
-from filer import settings as filer_settings
-from filer.models.foldermodels import Folder
-from filer.utils.compatibility import python_2_unicode_compatible
-from polymorphic import PolymorphicModel, PolymorphicManager
-import hashlib
-import os
+
+from . import mixins
+from .. import settings as filer_settings
+from ..fields.multistorage_file import MultiStorageFileField
+from ..utils.compatibility import LTE_DJANGO_1_7, python_2_unicode_compatible
+from .foldermodels import Folder
+
+try:
+    from polymorphic.models import PolymorphicModel
+    from polymorphic.managers import PolymorphicManager
+except ImportError:
+    # django-polymorphic < 0.8
+    from polymorphic import PolymorphicModel, PolymorphicManager
 
 
 class FileManager(PolymorphicManager):
@@ -50,7 +59,7 @@ class File(PolymorphicModel, mixins.IconsMixin):
         verbose_name=_('description'))
 
     owner = models.ForeignKey(getattr(settings, 'AUTH_USER_MODEL', 'auth.User'),
-        related_name='owned_%(class)ss',
+        related_name='owned_%(class)ss', on_delete=models.SET_NULL,
         null=True, blank=True, verbose_name=_('owner'))
 
     uploaded_at = models.DateTimeField(_('uploaded at'), auto_now_add=True)
@@ -59,8 +68,8 @@ class File(PolymorphicModel, mixins.IconsMixin):
     is_public = models.BooleanField(
         default=filer_settings.FILER_IS_PUBLIC_DEFAULT,
         verbose_name=_('Permissions disabled'),
-        help_text=_('Disable any permission checking for this ' +\
-                    'file. File will be publicly accessible ' +\
+        help_text=_('Disable any permission checking for this '
+                    'file. File will be publicly accessible '
                     'to anyone.'))
 
     objects = FileManager()
@@ -215,13 +224,27 @@ class File(PolymorphicModel, mixins.IconsMixin):
             text = "%s" % (self.name,)
         return text
 
-    def get_admin_url_path(self):
+    def get_admin_change_url(self):
+        if LTE_DJANGO_1_7:
+            model_name = self._meta.module_name
+        else:
+            model_name = self._meta.model_name
         return urlresolvers.reverse(
-            'admin:%s_%s_change' % (self._meta.app_label,
-                                    self._meta.module_name,),
+            'admin:{0}_{1}_change'.format(self._meta.app_label, model_name),
             args=(self.pk,)
         )
 
+    def get_admin_delete_url(self):
+        try:
+            # Django <=1.6
+            model_name = self._meta.module_name
+        except AttributeError:
+            # Django >1.6
+            model_name = self._meta.model_name
+        return urlresolvers.reverse(
+            'admin:{0}_{1}_delete'.format(self._meta.app_label, model_name,),
+            args=(self.pk,))
+
     @property
     def url(self):
         """
@@ -233,6 +256,19 @@ class File(PolymorphicModel, mixins.IconsMixin):
             r = ''
         return r
 
+    @property
+    def canonical_url(self):
+        url = ''
+        if self.file and self.is_public:
+            try:
+                url = urlresolvers.reverse('canonical', kwargs={
+                    'uploaded_at': self.uploaded_at.strftime('%s'),
+                    'file_id': self.id
+                })
+            except urlresolvers.NoReverseMatch:
+                pass  # No canonical url, return empty string
+        return url
+
     @property
     def path(self):
         try:
@@ -258,8 +294,8 @@ class File(PolymorphicModel, mixins.IconsMixin):
         Folder object
         """
         if not self.folder:
-            from filer.models.virtualitems import UnfiledImages
-            return UnfiledImages()
+            from .virtualitems import UnsortedImages
+            return UnsortedImages()
         else:
             return self.folder
 
@@ -279,7 +315,7 @@ class File(PolymorphicModel, mixins.IconsMixin):
     def duplicates(self):
         return File.objects.find_duplicates(self)
 
-    class Meta:
+    class Meta(object):
         app_label = 'filer'
         verbose_name = _('file')
         verbose_name_plural = _('files')
