@@ -1,6 +1,9 @@
-#-*- coding: utf-8 -*-
-from __future__ import unicode_literals
+# -*- coding: utf-8 -*-
 
+from __future__ import absolute_import, unicode_literals
+
+import mptt
+from django.conf import settings
 from django.contrib.auth import models as auth_models
 from django.core import urlresolvers
 from django.core.exceptions import ValidationError
@@ -8,12 +11,10 @@ from django.db import models
 from django.db.models import Q
 from django.utils.http import urlquote
 from django.utils.translation import ugettext_lazy as _
-from django.conf import settings
-from filer.models import mixins
-from filer import settings as filer_settings
-from filer.utils.compatibility import python_2_unicode_compatible
 
-import mptt
+from . import mixins
+from .. import settings as filer_settings
+from ..utils.compatibility import python_2_unicode_compatible
 
 
 class FolderManager(models.Manager):
@@ -103,13 +104,13 @@ class Folder(models.Model, mixins.IconsMixin):
     name = models.CharField(_('name'), max_length=255)
 
     owner = models.ForeignKey(getattr(settings, 'AUTH_USER_MODEL', 'auth.User'), verbose_name=('owner'),
-                              related_name='filer_owned_folders',
+                              related_name='filer_owned_folders', on_delete=models.SET_NULL,
                               null=True, blank=True)
 
     uploaded_at = models.DateTimeField(_('uploaded at'), auto_now_add=True)
 
     created_at = models.DateTimeField(_('created at'), auto_now_add=True)
-    modified_at = models.DateTimeField(_('modified at'),auto_now=True)
+    modified_at = models.DateTimeField(_('modified at'), auto_now=True)
 
     objects = FolderManager()
 
@@ -147,7 +148,7 @@ class Folder(models.Model, mixins.IconsMixin):
 
     @property
     def pretty_logical_path(self):
-        return "/%s" % "/".join([f.name for f in self.logical_path+[self]])
+        return "/%s" % "/".join([f.name for f in self.logical_path + [self]])
 
     @property
     def quoted_logical_path(self):
@@ -196,7 +197,7 @@ class Folder(models.Model, mixins.IconsMixin):
                     self.permission_cache[permission_type] = self.id in permission
             return self.permission_cache[permission_type]
 
-    def get_admin_url_path(self):
+    def get_admin_change_url(self):
         return urlresolvers.reverse('admin:filer_folder_change',
                                     args=(self.id,))
 
@@ -204,6 +205,17 @@ class Folder(models.Model, mixins.IconsMixin):
         return urlresolvers.reverse('admin:filer-directory_listing',
                                     args=(self.id,))
 
+    def get_admin_delete_url(self):
+        try:
+            # Django <=1.6
+            model_name = self._meta.module_name
+        except AttributeError:
+            # Django >1.6
+            model_name = self._meta.model_name
+        return urlresolvers.reverse(
+            'admin:{0}_{1}_delete'.format(self._meta.app_label, model_name,),
+            args=(self.pk,))
+
     def __str__(self):
         return "%s" % (self.name,)
 
@@ -214,7 +226,7 @@ class Folder(models.Model, mixins.IconsMixin):
         except Folder.DoesNotExist:
             return False
 
-    class Meta:
+    class Meta(object):
         unique_together = (('parent', 'name'),)
         ordering = ('name',)
         permissions = (("can_use_directory_listing",
@@ -254,7 +266,7 @@ class FolderPermission(models.Model):
 
     type = models.SmallIntegerField(_('type'), choices=TYPES, default=ALL)
     user = models.ForeignKey(getattr(settings, 'AUTH_USER_MODEL', 'auth.User'),
-                             related_name="filer_folder_permissions",
+                             related_name="filer_folder_permissions", on_delete=models.SET_NULL,
                              verbose_name=_("user"), blank=True, null=True)
     group = models.ForeignKey(auth_models.Group,
                               related_name="filer_folder_permissions",
@@ -291,8 +303,8 @@ class FolderPermission(models.Model):
                 perms.append('!%s' % s)
         perms = ', '.join(perms)
         return "Folder: '%s'->%s [%s] [%s]" % (
-                        name, str(self.TYPES[self.type][1]),
-                        perms, usergroup)
+            name, self.get_type_display(),
+            perms, usergroup)
 
     def clean(self):
         if self.type == self.ALL and self.folder:
@@ -304,7 +316,7 @@ class FolderPermission(models.Model):
         if not self.user and not self.group and not self.everybody:
             raise ValidationError('At least one of user, group, or "everybody" has to be selected.')
 
-    class Meta:
+    class Meta(object):
         verbose_name = _('folder permission')
         verbose_name_plural = _('folder permissions')
         app_label = 'filer'
