@@ -1,5 +1,7 @@
-#-*- coding: utf-8 -*-
-from filer.models import Clipboard
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import
+
+from . import Clipboard
 
 
 def discard_clipboard(clipboard):
