@@ -1,7 +1,12 @@
-#-*- coding: utf-8 -*-
-from django.template import Library
+# -*- coding: utf-8 -*-
+
+from __future__ import absolute_import
+
 import math
 
+from django.template import Library
+from django.utils import six
+
 register = Library()
 
 # The templatetag below is copied from sorl.thumbnail
@@ -49,9 +54,10 @@ def filesize(bytes, format='auto1024'):
     elif format not in ('auto1024', 'auto1000',
                         'auto1024long', 'auto1000long'):
         return bytes
+
     # Check for valid bytes
     try:
-        bytes = long(bytes)
+        bytes = int(bytes) if six.PY3 else long(bytes)  # NOQA - flake8/py3 reports error: long does not exists in py3
     except (ValueError, TypeError):
         return bytes
 
