@@ -1,9 +1,11 @@
-#-*- coding: utf-8 -*-
-#import zipfile
-# zipfile.open() is only available in Python 2.6, so we use the future version
-from django.core.files.uploadedfile import SimpleUploadedFile
+# -*- coding: utf-8 -*-
+
+from __future__ import absolute_import
+
 from zipfile import ZipFile
 
+from django.core.files.uploadedfile import SimpleUploadedFile
+
 
 def unzip(file_obj):
     """
